==> turgen_system-8.4.5.src.tar.bz2: turgen_system-8.4.5.src/src/turgen/tapeimage/FujiChunk.java <==
package turgen.tapeimage;

import java.io.InputStream;
import java.io.OutputStream;
import turgen.FileFormatException;


public class FujiChunk implements TapeImageChunk {

    private static final String type = "FUJI";
    private int length;
    private int[] data;
    private int aux;


    public int getAux() {
        return aux;
    }


    public String getType() {
        return type;
    }

    public int getLength() {
        return length;
    }

    public int[] getData() {
        return data;
    }

    public boolean isGeneretedUsingParent() {
        return false;
    }

    public void readFromStream(InputStream s) throws Exception {

        /*Read length and AUX*/
        int lengthLo = s.read();
        int lengthHi = s.read();
        int auxLo=s.read();
        int auxHi=s.read();

        if (lengthLo==-1 || lengthHi==-1 || auxLo==-1 || auxHi==-1) {
            throw new FileFormatException("Truncated FUJI chunk header");
        }

        length = lengthLo + (256*lengthHi);
        aux = auxLo + (256*auxHi);
        
        /*Read data*/
        data = new int[length];
        for(int i=0;i<length;i++) {
            int b = s.read();
            if (b==-1) throw new FileFormatException("Truncated FUJI chunk data");
            data[i]=b;
        }
        
    }

    public void writeToStream(OutputStream s) throws Exception {
        
    }

    public String toString() {
        return "FUJI ("+Integer.toString(length)+")";
    }

    public TapeImageChunk getParent() {
        return null;
    }

    

}

==> turgen_system-8.4.11.src.tar.bz2: turgen_system-8.4.11.src/src/turgen/tapeimage/FujiChunk.java <==
package turgen.tapeimage;

import java.io.InputStream;
import java.io.OutputStream;
import turgen.FileFormatException;


public class FujiChunk implements TapeImageChunk {

    private static final String type = "FUJI";
    private int length;
    private int[] data;
    private int aux;
    
    /** Get default FUJI chunk
     * 
     * @return Default FUJI chunk
     */
    public static FujiChunk getDefaultFujiChunk() {
        FujiChunk fc = new FujiChunk();
        fc.length=0;
        fc.data=new int[0];
        fc.aux=0;
        
        return fc;
    }

    public int getAux() {
        return aux;
    }


    public String getType() {
        return type;
    }

    public int getLength() {
        return length;
    }

    public int[] getData() {
        return data;
    }

    public boolean isGeneretedUsingParent() {
        return false;
    }

    public void readFromStream(InputStream s) throws Exception {

        /*Read length and AUX*/
        int lengthLo = s.read();
        int lengthHi = s.read();
        int auxLo=s.read();
        int auxHi=s.read();

        if (lengthLo==-1 || lengthHi==-1 || auxLo==-1 || auxHi==-1) {
            throw new FileFormatException("Truncated FUJI chunk header");
        }

        length = lengthLo + (256*lengthHi);
        aux = auxLo + (256*auxHi);
        
        /*Read data*/
        data = new int[length];
        for(int i=0;i<length;i++) {
            int b = s.read();
            if (b==-1) throw new FileFormatException("Truncated FUJI chunk data");
            data[i]=b;
        }
        
    }

    public void writeToStream(java.io.DataOutputStream s) throws Exception {
        s.writeBytes("FUJI");
        s.write(length%256);
        s.write(length/256);
        s.write(aux%256);
        s.write(aux/256);
        for(int i=0;i<data.length;i++) {
            s.write(data[i]);
        }
        
    }

    public String toString() {
        return "FUJI ("+Integer.toString(length)+")";
    }

    public TapeImageChunk getParent() {
        return null;
    }

    

}
